=== modified file 'loggerhead/apps/branch.py'
--- loggerhead/apps/branch.py	2008-06-25 06:05:09 +0000
+++ loggerhead/apps/branch.py	2008-06-25 00:07:04 +0000
@@ -3,6 +3,7 @@
 
 from paste import request
 from paste import httpexceptions
+from paste.wsgiwrappers import WSGIRequest, WSGIResponse
 
 from loggerhead.apps import static_app
 from loggerhead.changecache import FileChangeCache
@@ -88,4 +89,5 @@
         if cls is None:
             raise httpexceptions.HTTPNotFound()
         c = cls(self)
-        return c(environ, start_response)
+        req = WSGIRequest(environ)
+        return c.default(req, start_response)

=== modified file 'loggerhead/controllers/__init__.py'
--- loggerhead/controllers/__init__.py	2008-06-25 06:05:09 +0000
+++ loggerhead/controllers/__init__.py	2008-06-25 00:07:04 +0000
@@ -16,41 +16,14 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import re
 import time
 
-from paste.request import path_info_pop, parse_querystring
+from paste.request import path_info_pop
 
 from loggerhead import util
 from loggerhead.templatefunctions import templatefunctions
 from loggerhead.zptsupport import load_template
 
-class BufferingWriter:
-
-    def __init__(self, writefunc, buf_limit):
-        self.bytes = 0
-        self.buf = []
-        self.buflen = 0
-        self.writefunc = writefunc
-        self.bytes_saved = 0
-        self.buf_limit = buf_limit
-
-    def flush(self):
-        chunk = ''.join(self.buf)
-        chunk = re.sub(r'\s*\n\s*', '\n', chunk)
-        chunk = re.sub(r'[ \t]+', ' ', chunk)
-        self.bytes_saved += self.buflen - len(chunk)
-        self.writefunc(chunk)
-        self.buf = []
-        self.buflen = 0
-
-    def write(self, data):
-        self.buf.append(data)
-        self.buflen += len(data)
-        self.bytes += len(data)
-        if self.buflen > self.buf_limit:
-            self.flush()
-
 class TemplatedBranchView(object):
 
     template_path = None
@@ -59,17 +32,17 @@
         self._branch = branch
         self.log = branch.log
 
-    def __call__(self, environ, start_response):
+    def default(self, request, start_response):
         z = time.time()
         h = self._branch.history
-        kw = dict(parse_querystring(environ))
+        kw = request.GET
         util.set_context(kw)
 
         h._branch.lock_read()
         try:
             args = []
             while 1:
-                arg = path_info_pop(environ)
+                arg = path_info_pop(request.environ)
                 if arg is None:
                     break
                 args.append(arg)
@@ -91,11 +64,16 @@
             writer = start_response("200 OK", headers.items())
             template = load_template(self.template_path)
             z = time.time()
-            w = BufferingWriter(writer, 8192)
+            class W:
+                def __init__(self):
+                    self.bytes = 0
+                def write(self, data):
+                    self.bytes += len(data)
+                    writer(data)
+            w = W()
             template.expand_into(w, **vals)
-            w.flush()
-            self.log.info('Rendering %s: %r secs, %s bytes, %s (%2.1f%%) bytes saved' % (
-                self.__class__.__name__, time.time() - z, w.bytes, w.bytes_saved, 100.0*w.bytes_saved/w.bytes))
+            self.log.info('Rendering %s: %r secs, %s bytes' % (
+                self.__class__.__name__, time.time() - z, w.bytes))
             return []
         finally:
             h._branch.unlock()

=== modified file 'loggerhead/controllers/download_ui.py'
--- loggerhead/controllers/download_ui.py	2008-06-25 06:05:09 +0000
+++ loggerhead/controllers/download_ui.py	2008-06-25 00:07:04 +0000
@@ -34,7 +34,7 @@
         self._branch = branch
         self.log = branch.log
 
-    def __call__(self, environ, start_response):
+    def default(self, request, start_response):
         # /download/<rev_id>/<file_id>/[filename]
         z = time.time()
         h = self._branch.history
@@ -43,7 +43,7 @@
         try:
             args = []
             while 1:
-                arg = path_info_pop(environ)
+                arg = path_info_pop(request.environ)
                 if arg is None:
                     break
                 args.append(arg)

=== modified file 'loggerhead/util.py'
--- loggerhead/util.py	2008-06-25 06:03:26 +0000
+++ loggerhead/util.py	2008-06-20 02:20:05 +0000
@@ -411,6 +411,21 @@
     return _decorator
 
 
+@decorator
+def strip_whitespace(f):
+    def _f(*a, **kw):
+        out = f(*a, **kw)
+        orig_len = len(out)
+        out = re.sub(r'\n\s+', '\n', out)
+        out = re.sub(r'[ \t]+', ' ', out)
+        out = re.sub(r'\s+\n', '\n', out)
+        new_len = len(out)
+        log.debug('Saved %sB (%d%%) by stripping whitespace.',
+                  human_size(orig_len - new_len),
+                  round(100.0 - float(new_len) * 100.0 / float(orig_len)))
+        return out
+    return _f
+
 
 @decorator
 def lsprof(f):

